@@ -25,8 +25,8 @@ import coloredlogs
 import looker_sdk
 from looker_sdk import models
 import pandas as pd
-from utils import parsing_sql
-from utils import create_df
+from lmanage.utils import parsing_sql
+from lmanage.utils import create_df
 
 logger = logging.getLogger(__name__)
 coloredlogs.install(level='INFO')
