@@ -18,12 +18,19 @@ def return_error_message(input: str):
     return err_response
 
 
-def return_sleep_message():
-    sleep(3)
-    logger.warn('Looker is overwhelmed sleeping for 3 secs')
+def return_sleep_message(call_number=0):
+    call_number = call_number+1
+    sleep_number = 2 ** call_number
+    sleep(sleep_number)
+    logger.warn(f'Looker is overwhelmed sleeping for {sleep_number} secs')
 
 
 def dedup_list_of_dicts(input: list):
     stringinput = list(set([str(x) for x in input]))
     deduped = [ast.literal_eval(x) for x in stringinput]
     return deduped
+
+
+def counter(i=0):
+    i += 1
+    return i
